#!/bin/bash
set -e
usage="$(basename "$0") [-h] [-p path] [-c cores] [-m mpi] -- program to run the CP2K CDFT tutorial calculations

where:
    -h  show this help text
    -p  path to CP2K installation (default: .)
    -c  number of MPI processes to use for calculation (default: 2)
    -m  name and path of program to execute MPI programs (default: mpiexec)"

ncores=2
path="."
mpi_program="mpiexec"

while getopts ':hp:c:m:' option; do
    case "$option" in
        h)
            echo "$usage"
            exit
            ;;
        p)
            path="$OPTARG"
            ;;
        c)
            ncores="$OPTARG"
            if ! [[ $ncores =~ ^-?[0-9]+$ ]]; then
                echo "value passed to -c must be an integer" >&2
                echo "$usage" >&2
                exit 1
            fi
           ;;
        m)
            mpi_program="$OPTARG"
            ;;
        :)
            printf "missing argument for -%s\n" "$OPTARG" >&2
            echo "$usage" >&2
            exit 1
            ;;
       \?)
            printf "illegal option: -%s\n" "$OPTARG" >&2
            echo "$usage" >&2
            exit 1
            ;;
    esac
done
shift $((OPTIND - 1))

export CP2K_PATH="$path"
cp2k_suffix=".popt"
if [[ $ncores =~ 1 ]]; then
    mpi_command=""
    cp2k_suffix=".popt"
else
    mpi_command="$mpi_program -n $ncores"
fi
run_cp2k="$mpi_command ${CP2K_PATH}/cp2k${cp2k_suffix}"

# Standard DFT calculation
template="energy"
xyzfile="nacl.xyz"
project_file="${xyzfile%%.xyz}-pbe-energy"
use_becke="FALSE"
restart_wfn="FALSE"
target="0.0"
strength="0.0"
wfnfile="dummy.wfn"
# Fill in template
sed -e "s|EXTERNAL_XYZNAME|${xyzfile}|g" \
    -e "s/EXTERNAL_PROJNAME/${project_file}/g" \
    -e "s|EXTERNAL_WFNRESTART_1|${wfnfile}|g" \
    -e "s/EXTERNAL_RESTART_WFN_1/${restart_wfn}/g" \
    -e "s/EXTERNAL_STR/${strength}/g" \
    -e "s/EXTERNAL_TARGET/${target}/g" \
    -e "s/EXTERNAL_BECKE_ACTIVE/${use_becke}/g" \
    "${template}.inp" > "${template}_run.inp"
# Run calculation
echo "Calculating DFT ground state"
$run_cp2k "${template}_run.inp" >> "${project_file}.out"
